Data (data package)
=========================


Base class of DataHolder
------------------------

.. autoclass:: gadma.data.data.DataHolder
   :members:
   :undoc-members:
   :show-inheritance:

Input data types
----------------

.. automodule:: gadma.data.data
   :members: SFSDataHolder, VCFDataHolder
   :undoc-members:
   :show-inheritance:
